@@ -4,6 +4,7 @@ use Mojo::File qw(path);
 use Mojolicious::Types;
 use Mojo::Path;
 use Mojo::Util;# qw(decode);
+use Scalar::Util 'weaken';
 
 my $PKG = __PACKAGE__;
 
@@ -78,7 +79,7 @@ sub register {# none magic
     unless $self->app->renderer->helpers->{'pod_to_html'} && ($self->render_pod // '') eq 0 ;
   
   # PATCH EMIT CHUNK
-  $self->_patch_emit_chunk()
+  $self->_hook_chunk()
     if defined $self->max_upload_size;
   
   return ($app, $self);
@@ -149,16 +150,12 @@ sub is_admin {# as helper
 }
 
 my $patched;
-sub _patch_emit_chunk {
+sub _hook_chunk {
   my $self = shift;
   
-  _patch_chunk() unless $patched++;
-  
-  #~ my $r1 = $self->app->routes->lookup($self->routes_names->[1]);
-  #~ warn  'POST ROUTE #2', $r1;
-  #~ my $r2 = $self->app->routes->lookup($self->routes_names->[3]);
-  #~ warn  'POST ROUTE #4', $r2;
+  _patch_emit_chunk() unless $patched++;
   
+  weaken $self;
   $self->app->hook(after_build_tx => sub {
     my ($tx, $app) = @_;
       $tx->once('chunk'=>sub {
@@ -173,7 +170,7 @@ sub _patch_emit_chunk {
       
       #~ warn "TX CHUNK ROUTE: ", $route->name;# eq $self->routes_names->[1] || $route->name eq $self->routes_names->[3]);#Mojo::Util::dumper($url);, length($chunk)
       $tx->req->max_message_size($self->max_upload_size)
-        if $route->name eq $self->routes_names->[1] || $route->name eq $self->routes_names->[3]
+        if ($route->name eq $self->routes_names->[1]) || ($route->name eq $self->routes_names->[3])
       # TODO admin session
       
     });
@@ -181,7 +178,7 @@ sub _patch_emit_chunk {
   
 }
 
-sub _patch_chunk {
+sub _patch_emit_chunk {
   
   Mojo::Util::monkey_patch 'Mojo::Transaction::HTTP', 'server_read' => sub {
     my ($self, $chunk) = @_;
@@ -201,7 +198,7 @@ sub _patch_chunk {
   
 }
 
-our $VERSION = '0.071';
+our $VERSION = '0.072';
 
 ##############################################
 package __internal__::Markdown;
@@ -238,7 +235,7 @@ Mojolicious::Plugin::StaticShare - browse, upload, copy, move, delete, edit, ren
 
 =head1 VERSION
 
-0.071
+0.072
 
 =head1 SYNOPSIS
 
@@ -381,9 +378,13 @@ Boolean to disable/enable uploads for public users. Defaults to undef (disable).
 
 =head2 max_upload_size
 
-  max_upload_size=>0, # unlimited
+  max_upload_size=>0, # unlimited POST
 
-Numeric value limiting uploads size for route. See L<Mojolicious#max_request_size>, L<Mojolicious#build_tx>.
+Numeric value limiting uploads size for route.
+WARN-EXPIRIMENTAL patching of L<Mojo::Transaction::HTTP#server_read>
+for emit chunk event.
+
+See also L<Mojolicious#max_request_size>, L<Mojolicious#build_tx>.
 
 =head1 Extended markdown & pod
 
